/*
* Auftrag: Microcontroller Projekt
*---------------------------------------------------------
* Modul:   Receive
* Version: v14 
* Autor: TEAM ESCM
*---------------------------------------------------------
* Aenderungen: (neueste an oberster Stelle)
* 15.06.2014  ARMA		Source-dokumentation
* 20.06.2014  ALLE		Doku 		
*---------------------------------------------------------*/


/*
	Includes
*/
#include "stm32f4xx_conf.h"
#include "stm32f4xx.h"

/*
	Globale Variablen
*/
EXTI_InitTypeDef EXTI_InitStructure;
GPIO_InitTypeDef GPIO_InitStructure;
NVIC_InitTypeDef NVIC_InitStructure;



/**
  * @brief  Stromversorgung und Takt fr GPIO und USART aktivieren					
  * @param  None
  * @retval None
  */
void RCC_initialisieren(void){	
	
	
		/* Fr USART2 */
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_SYSCFG, ENABLE); // EXTI mit Takt versorgen
		RCC_APB1PeriphClockCmd(RCC_APB1Periph_USART2, ENABLE); // USART mit Takt versorgen
	  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOA, ENABLE);  // GPIOA mit Takt versorgen

		/* Fr Empfangen */
		RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOC, ENABLE); // GPIOC mit Takt versorgen
	
}

/**
  * @brief  GPIO Pins konfigurieren
	* 				Receive:	GPIOC(Pin 0-3 Daten,Pin 15 Steuerleitung)
	*					USART:		GPIOA(Pin 2 Tx)
  * @param  None
  * @retval None
  */
void GPIO_initialisieren(void){


	 /* Receivedata (Daten)*/
		GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;	// Ports als Input definieren
		GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_3; // Pins 0,1,2,3 aktivieren
	  GPIO_InitStructure.GPIO_PuPd=GPIO_PuPd_DOWN; // Pull Down geschaltet
		GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;	// Abtastfrequenz auf 2MHz
		GPIO_Init(GPIOC, &GPIO_InitStructure); // GPIOC Konfiguration bergeben  , Pointer auf Struktur mit Config

		/* Steuerleitung */
		GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN; // Port als Input definieren
		GPIO_InitStructure.GPIO_Pin = GPIO_Pin_15; // Pin 15 aktivieren
		GPIO_InitStructure.GPIO_PuPd=GPIO_PuPd_DOWN; // Pull Down geschaltet
		GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz; // Abtastfrequenz auf 2MHz
		GPIO_Init(GPIOC, &GPIO_InitStructure); // GPIOC Konfiguration bergeben  , Pointer auf Struktur mit Config
 
 
		/* USART -> TX - Leitung*/
		GPIO_InitStructure.GPIO_Mode=GPIO_Mode_AF; // Port als Alternate Function 
		GPIO_InitStructure.GPIO_OType=GPIO_OType_PP; // Push-pull 
		GPIO_InitStructure.GPIO_Pin=GPIO_Pin_2; // Pin2 aktivieren
		GPIO_InitStructure.GPIO_PuPd=GPIO_PuPd_NOPULL; // deaktivere pull-up/pull-down Widerstand
		GPIO_InitStructure.GPIO_Speed=GPIO_Speed_2MHz; // Abtastfrequenz auf 2MHz
	 
		GPIO_Init(GPIOA, &GPIO_InitStructure); // GPIOA Konfiguration bergeben  , Pointer auf Struktur mit Config
		
		GPIO_PinAFConfig(GPIOA, GPIO_PinSource2, GPIO_AF_USART2); // Pin A2 an USART2 weiterleiten 


}


/**
  * @brief  USART initialisieren fr Ausgabe					
  * @param  None
  * @retval None
  */
void USART2_initialisieren(void)
{
		USART_InitTypeDef USART_InitTypeStructure; // Struktur fr USART Konfiguration
	  USART_InitTypeStructure.USART_BaudRate = 9600; // Baudrate auf 9600 setzen
	  USART_InitTypeStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None; // kein Flow Control
	  USART_InitTypeStructure.USART_Mode = USART_Mode_Tx; // Sendemodus
	  USART_InitTypeStructure.USART_Parity = USART_Parity_No; //Kein Parity -Bitsd
	  USART_InitTypeStructure.USART_StopBits = USART_StopBits_1; // 1-Stopbit
	  USART_InitTypeStructure.USART_WordLength = USART_WordLength_8b; // 8 Datenbit
	  USART_Init(USART2,&USART_InitTypeStructure); // USART2 Konfiguration bergeben  , Pointer auf Struktur mit Config
	
	  USART_Cmd(USART2, ENABLE); // USART wird hier aktiviert
}

/**
  * @brief  EXTI auf PE15 konfigurieren					
  * @param  None
  * @retval None
  */
void EXTILine15_10_Config(void)
{	

  SYSCFG_EXTILineConfig(EXTI_PortSourceGPIOC, EXTI_PinSource15); // Verbinde EXTILine15_10 mit PC15
	

  EXTI_InitStructure.EXTI_Line = EXTI_Line15;	// EXTI_Line 15
  EXTI_InitStructure.EXTI_Mode = EXTI_Mode_Interrupt; // Auf Interrupt-Mode
  // EXTI_InitStructure.EXTI_Trigger = EXTI_Trigger_Falling;  
	EXTI_InitStructure.EXTI_Trigger = EXTI_Trigger_Rising; // steigende Flankenerkennung
  EXTI_InitStructure.EXTI_LineCmd = ENABLE; // EXTI aktivieren
  EXTI_Init(&EXTI_InitStructure);  
	
 
  NVIC_InitStructure.NVIC_IRQChannel = EXTI15_10_IRQn; // NVIC-Kanal 15_10 fr EXTI_Line 15
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0x01; // PreemtionPrio = 1
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0x01; // SubPrio = 1
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE; // NVIC-Kanal aktivieren
  NVIC_Init(&NVIC_InitStructure); 
	
}


/**
  * @brief  Main-Funktion
  * @param  None
  * @retval None
  */
int main(void){

	/* Stromversorgung / mit Takt versorgen  */
	RCC_initialisieren(); 
	/* Pins konfigurieren */
	GPIO_initialisieren();
	/* Usart konfigurieren */ 	
	USART2_initialisieren();  
	/* Interrupt auf Steuerleitung */
	EXTILine15_10_Config(); 

	/* Auf interrupt warten */
  while(1){} 

}

